#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""CRS constants"""

CRS_CATALOG_DOCUMENTATION = "https://community.opengroup.org/osdu/documentation/-/wikis/OSDU-(C)/Design-and-Implementation/OpenDES-API-Specifications/Documentation/core-services/CRSCatalogService"
CRS_CATALOG_SERVICE_NAME = "CRS Catalog service"
CRS_CATALOG_STATUS_PATH = "../_ah/readiness_check"
CRS_CATALOG_SWAGGER_PATH = "../swagger-ui.html"

CRS_CONVERTER_SERVICE_NAME = "CRS Converter service"
CRS_CONVERTER_STATUS_PATH = "../_ah/readiness_check"
CRS_CONVERTER_SWAGGER_PATH = "../swagger-ui.html"
